[![https://pypi.org/project/clitify/](https://cdn.discordapp.com/attachments/507519157387132940/979538526259523615/unknown.png)](https://pypi.org/project/clitify/)

# Install
```sh
pip install clitify
```

# Run
```sh
# Like a song
splike

# Move song position
spseek +10 # +10 seconds
spseek -2.5 # -2.5 seconds

# List song queue when on playlist
spq
```
